==> haskell-edisoncore-1.3.1.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonCore
version: 1.3.1.1
id: EdisonCore-1.3.1.1-14FKBfIx4CQHL5lx2F3b2v
key: EdisonCore-1.3.1.1-14FKBfIx4CQHL5lx2F3b2v
license: OtherLicense
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficent, purely-functional data structures (Core Implementations)
description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.
category: Data Structures
author: Chris Okasaki
exposed: True
exposed-modules:
    Data.Edison.Assoc.Defaults Data.Edison.Assoc.AssocList
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Concrete.FingerTree
    Data.Edison.Coll.Defaults Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.EnumSet
    Data.Edison.Coll.UnbalancedSet Data.Edison.Seq.Defaults
    Data.Edison.Seq.BankersQueue Data.Edison.Seq.BinaryRandList
    Data.Edison.Seq.BraunSeq Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq
abi: 3de0a14f19ce0707472cc3ff78b7ec24
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/EdisonCore-1.3.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/EdisonCore-1.3.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/EdisonCore-1.3.1.1
hs-libraries: HSEdisonCore-1.3.1.1-14FKBfIx4CQHL5lx2F3b2v
depends:
    EdisonAPI-1.3.1-KjkUBwUQ9QtGMmEyFW5iNe
    QuickCheck-2.9.2-AzbjWrJo3WFD60ZxKurQ3s array-0.5.1.1 base-4.9.0.0
    containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
haddock-interfaces: /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html: /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edisoncore-1.3.1.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-edisoncore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: EdisonCore
version: 1.3.1.1
id: EdisonCore-1.3.1.1-DMryhUxAVMr5wgfirXDLtr
key: EdisonCore-1.3.1.1-DMryhUxAVMr5wgfirXDLtr
license: OtherLicense
maintainer: robdockins AT fastmail DOT fm
stability: Stable
homepage: http://rwd.rdockins.name/edison/home/
synopsis: A library of efficent, purely-functional data structures (Core Implementations)
description:
    This package provides the core Edison data structure implementations,
    including multiple sequence, set, bag, and finite map concrete
    implementations with various performance characteristics. The
    implementations in this package have no dependencies other than those
    commonly bundled with Haskell compilers.
category: Data Structures
author: Chris Okasaki
exposed: True
exposed-modules:
    Data.Edison.Assoc.Defaults Data.Edison.Assoc.AssocList
    Data.Edison.Assoc.PatriciaLoMap Data.Edison.Assoc.StandardMap
    Data.Edison.Assoc.TernaryTrie Data.Edison.Concrete.FingerTree
    Data.Edison.Coll.Defaults Data.Edison.Coll.LazyPairingHeap
    Data.Edison.Coll.LeftistHeap Data.Edison.Coll.MinHeap
    Data.Edison.Coll.SkewHeap Data.Edison.Coll.SplayHeap
    Data.Edison.Coll.StandardSet Data.Edison.Coll.EnumSet
    Data.Edison.Coll.UnbalancedSet Data.Edison.Seq.Defaults
    Data.Edison.Seq.BankersQueue Data.Edison.Seq.BinaryRandList
    Data.Edison.Seq.BraunSeq Data.Edison.Seq.FingerSeq
    Data.Edison.Seq.JoinList Data.Edison.Seq.MyersStack
    Data.Edison.Seq.RandList Data.Edison.Seq.RevSeq
    Data.Edison.Seq.SimpleQueue Data.Edison.Seq.SizedSeq
abi: 430586ee85941d3c7d3045e2333b611d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/EdisonCore-1.3.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/EdisonCore-1.3.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/EdisonCore-1.3.1.1
hs-libraries: HSEdisonCore-1.3.1.1-DMryhUxAVMr5wgfirXDLtr
depends:
    EdisonAPI-1.3.1-KjkUBwUQ9QtGMmEyFW5iNe
    QuickCheck-2.9.2-3a8nWdLsV8cEn9LdMoftRm array-0.5.1.1 base-4.9.0.0
    containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
haddock-interfaces: /usr/share/doc/haskell-edisoncore/html/EdisonCore.haddock
haddock-html: /usr/share/doc/haskell-edisoncore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
